==> huaweicloudsdkprojectman-3.1.79-py2.py3-none-any.whl: huaweicloudsdkprojectman/v4/model/show_project_info_v4_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ShowProjectInfoV4Response(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'project': 'GetProjectInfoV4ResultProject'
    }

    attribute_map = {
        'project': 'project'
    }

    def __init__(self, project=None):
        """ShowProjectInfoV4Response

        The model defined in huaweicloud sdk

        :param project: 
        :type project: :class:`huaweicloudsdkprojectman.v4.GetProjectInfoV4ResultProject`
        """
        
        super(ShowProjectInfoV4Response, self).__init__()

        self._project = None
        self.discriminator = None

        if project is not None:
            self.project = project

    @property
    def project(self):
        """Gets the project of this ShowProjectInfoV4Response.

        :return: The project of this ShowProjectInfoV4Response.
        :rtype: :class:`huaweicloudsdkprojectman.v4.GetProjectInfoV4ResultProject`
        """
        return self._project

    @project.setter
    def project(self, project):
        """Sets the project of this ShowProjectInfoV4Response.

        :param project: The project of this ShowProjectInfoV4Response.
        :type project: :class:`huaweicloudsdkprojectman.v4.GetProjectInfoV4ResultProject`
        """
        self._project = project

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ShowProjectInfoV4Response):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkprojectman-3.1.145-py2.py3-none-any.whl: huaweicloudsdkprojectman/v4/model/show_project_info_v4_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ShowProjectInfoV4Response(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'project': 'GetProjectInfoV4ResultProject'
    }

    attribute_map = {
        'project': 'project'
    }

    def __init__(self, project=None):
        r"""ShowProjectInfoV4Response

        The model defined in huaweicloud sdk

        :param project: 
        :type project: :class:`huaweicloudsdkprojectman.v4.GetProjectInfoV4ResultProject`
        """
        
        super(ShowProjectInfoV4Response, self).__init__()

        self._project = None
        self.discriminator = None

        if project is not None:
            self.project = project

    @property
    def project(self):
        r"""Gets the project of this ShowProjectInfoV4Response.

        :return: The project of this ShowProjectInfoV4Response.
        :rtype: :class:`huaweicloudsdkprojectman.v4.GetProjectInfoV4ResultProject`
        """
        return self._project

    @project.setter
    def project(self, project):
        r"""Sets the project of this ShowProjectInfoV4Response.

        :param project: The project of this ShowProjectInfoV4Response.
        :type project: :class:`huaweicloudsdkprojectman.v4.GetProjectInfoV4ResultProject`
        """
        self._project = project

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ShowProjectInfoV4Response):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
